/**
*数据库操作辅助类,定义对象、数据操作方法都在这里定义
*/
var dbname='yearstopic';/*数据库名*/
var dbdesc = '历年真题题库'; /*数据库描述*/
var dbsize = 20*1024*1024; /*数据库大小*/
var dataBase = null; /*暂存数据库对象*/
/*数据库中的表单名*/
var websqlTable = "websqlTable";
/**
 * 打开数据库
 * @returns  dataBase:打开成功   null:打开失败
 */
function websqlOpenDB(){
    /*数据库有就打开 没有就创建*/
   var version = window.localStorage.DBversion;
    dataBase = window.openDatabase(dbname, version, dbdesc, dbsize);
    if (dataBase) {
        console.log("数据库创建/打开成功!");
    } else{
        console.log("数据库创建/打开失败！");
    }
    return dataBase;
}
function changeDataBaseVersion(old_version,new_version){
	var db  = websqlOpenDB();
	db.changeVersion(old_version,new_version,null,function(err){},null)
	window.localStorage.DBversion = new_version;
}
/**
 * 新建数据库里面的表单
 * @param tableName:表单名
 */
function websqlCreatTable(tableName){
//  chinaAreaOpenDB();
    var creatTableSQL = 'CREATE TABLE IF  NOT EXISTS '+ tableName+'(ID text,QUESTION text)';
    dataBase.transaction(function (ctx,result) {
        ctx.executeSql(creatTableSQL,[],function(ctx,result){
            console.log("表创建成功 " + tableName);
        },function(tx, error){
            console.log('创建表失败:' + tableName + error.message);
        });
    });
}
/**
 * 往表单里面插入数据
 * @param tableName:表单名
 * @param ID:题目id
 * @param QUESTION:题目
 * @param ANSWER:答案
 * @param JX:解析
 * @param CATEGORY:分类ID
 * @param TOPIC_LIST:答案选项
 * @param TYPE:题目类型（专利/相关）
 */
function websqlInsterDataToTable(tableName,id,question){
	var question = JSON.stringify(question);
    var insterTableSQL = 'INSERT INTO ' + tableName + ' VALUES (?,?)';
    dataBase.transaction(function (ctx) {
    	ctx.executeSql(insterTableSQL,[id,question],function (ctx,result){
            console.log("插入" + tableName + id + "成功");
        },
        function (tx, error) {
            console.log('插入失败: ' + error.message);
        });
    });
}
/**
 * 获取数据库一个表单里面的所有数据
 * @param tableName:表单名
 * 返回数据集合
 */
function websqlGetAllData(tableName,fn){
    var selectALLSQL = 'SELECT * FROM ' + tableName;
    dataBase.transaction(function (ctx) {
        ctx.executeSql(selectALLSQL,[],function (ctx,result){
            console.log('查询成功: ' + tableName +'__'+ result.rows.length);
            var len = result.rows.length;
            var queryDataArray = [];
            for(var i = 0;i < len;i++) {
            		queryDataArray.push(JSON.parse(result.rows.item(i).QUESTION));
            }
            fn(queryDataArray);
        },
        function (tx, error) {
            console.log('查询失败: ' + error.message);
        });
    });
}
//查询所有数据，获取json格式
function websqlGetAllDataJson(tableName,fn){
    var selectALLSQL = 'SELECT * FROM ' + tableName;
    dataBase.transaction(function (ctx) {
        ctx.executeSql(selectALLSQL,[],function (ctx,result){
            console.log('查询成功: ' + tableName +'__'+ result.rows.length);
            var len = result.rows.length;
            var queryDataArray = {};
            for(var i = 0;i < len;i++) {
            	var id = result.rows.item(i).ID;
            	id = id.replace('.0','');
            	queryDataArray[id] = JSON.parse(result.rows.item(i).QUESTION);
            }
            fn(queryDataArray);
        },
        function (tx, error) {
            console.log('查询失败: ' + error.message);
        });
    });
}
/**
 * 获取数据库一个表单里面的部分数据
 * @param tableName:表单名
 * @param name:姓名
 */
function websqlGetAData(tableName,id,fn){
    var selectSQL = 'SELECT * FROM ' + tableName + ' WHERE ID = ?'
    dataBase.transaction(function (ctx) {
        ctx.executeSql(selectSQL,[id+'.0'],function (ctx,result){
        	fn && fn(JSON.parse(result.rows.item(0).QUESTION))
        },
        function (tx, error) {
            console.log('查询失败: ' + error.message);
        });
    });
}
function webSqlDeleteTable(tabName){
	dataBase.transaction(function(tx) {
		tx.executeSql('DROP TABLE '+tabName+'');  
		console.log('删除表'+tabName+'成功')
	},
	function(tx,err){
		console.log('删除表'+tabName+'失败')
	})
}
/**
 * 删除表单里的全部数据
 * @param tableName:表单名
 */
function websqlDeleteAllDataFromTable(tableName){
    var deleteTableSQL = 'DELETE FROM ' + tableName;
    localStorage.removeItem(tableName);
    dataBase.transaction(function (ctx,result) {
        ctx.executeSql(deleteTableSQL,[],function(ctx,result){
            console.log("删除表成功 " + tableName);
        },function(tx, error){ 
            console.log('删除表失败:' + tableName + error.message);
        });
    });
}
/**
 * 根据name删除数据
 * @param tableName:表单名
 * @param name:数据的姓名
 */
function websqlDeleteADataFromTable(tableName,name){
    var deleteDataSQL = 'DELETE FROM ' + tableName + ' WHERE NAME = ?';
    localStorage.removeItem(tableName);
    dataBase.transaction(function (ctx,result) {
        ctx.executeSql(deleteDataSQL,[name],function(ctx,result){
        },function(tx, error){ 
        });
    });
}
/**
 * 根据name修改数据
 * @param tableName:表单名
 * @param name:姓名
 * @param age:年龄
 */
function websqlUpdateAData(tableName,id,question){
	var question = JSON.stringify(question)
    var updateDataSQL = 'UPDATE ' + tableName + ' SET QUESTION = ? WHERE ID = ?';
    dataBase.transaction(function (ctx,result) {
        ctx.executeSql(updateDataSQL,[question,id],function(ctx,result){
            console.log("更新成功 " + tableName + id);
        },function(tx, error){
            console.log('更新失败:' + tableName  + id + error.message);
        });
    });
}